@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -19,7 +19,7 @@
 
 """
 
-from nuitka.utils import Utils
+from nuitka.PythonVersions import python_version
 
 from .ConstantCodes import getConstantCode
 from .ErrorCodes import (
@@ -43,7 +43,7 @@ from .templates.CodeTemplatesGeneratorFunction import (
     template_genfunc_yielder_body_template,
     template_genfunc_yielder_decl_template
 )
-from .VariableCodes import getLocalVariableInitCode, getVariableCode
+from .VariableCodes import getLocalVariableCodeType, getLocalVariableInitCode
 
 
 def getGeneratorObjectDeclCode(function_identifier):
@@ -59,6 +59,7 @@ def getGeneratorObjectCode(context, function_identifier, user_variables,
     for user_variable in user_variables + temp_variables:
         function_locals.append(
             getLocalVariableInitCode(
+                context  = context,
                 variable = user_variable,
             )
         )
@@ -119,7 +120,7 @@ def generateMakeGeneratorObjectCode(to_name, expression, emit, context):
 
     closure_variables = generator_object_body.getClosureVariables()
 
-    if Utils.python_version < 350 or context.isForDirectCall():
+    if python_version < 350 or context.isForDirectCall():
         generator_name_obj = getConstantCode(
             constant = generator_object_body.getFunctionName(),
             context  = context
@@ -127,7 +128,7 @@ def generateMakeGeneratorObjectCode(to_name, expression, emit, context):
     else:
         generator_name_obj = "self->m_name"
 
-    if Utils.python_version < 350:
+    if python_version < 350:
         generator_qualname_obj = "NULL"
     elif not context.isForDirectCall():
         generator_qualname_obj = "self->m_qualname"
@@ -151,30 +152,29 @@ def generateMakeGeneratorObjectCode(to_name, expression, emit, context):
         closure_copy = []
 
         for count, variable in enumerate(closure_variables):
-            variable_code = getVariableCode(
-                context  = context,
-                variable = variable
-            )
+            variable_code_name, variable_c_type = getLocalVariableCodeType(context, variable)
 
             # Generators might not use them, but they still need to be put there.
             # TODO: But they don't have to be cells.
-            if not variable.isSharedTechnically():
+            if variable_c_type == "PyObject *":
                 closure_copy.append(
                     "closure[%d] = PyCell_NEW0( %s );" % (
                         count,
-                        variable_code
+                        variable_code_name
                     )
                 )
-            else:
+            elif variable_c_type == "PyCellObject *":
                 closure_copy.append(
                     "closure[%d] = %s;" % (
                         count,
-                        variable_code
+                        variable_code_name
                     )
                 )
                 closure_copy.append(
                     "Py_INCREF( closure[%d] );" % count
                 )
+            else:
+                assert False, variable
 
         closure_making = template_function_closure_making % {
             "closure_copy"  : indented(closure_copy),
