@@ -157,7 +157,7 @@ class ExpressionSelectMetaclass(ExpressionChildrenHavingBase):
             source_ref = source_ref
         )
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         # TODO: Meta class selection is very computable, and should be done.
         return self, None, None
 
@@ -185,7 +185,7 @@ class ExpressionBuiltinType3(ExpressionChildrenHavingBase):
     getBases = ExpressionChildrenHavingBase.childGetter("bases")
     getDict = ExpressionChildrenHavingBase.childGetter("dict")
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         # TODO: Should be compile time computable if bases and dict are.
 
         return self, None, None
