@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -23,9 +23,12 @@ to do.
 """
 
 from nuitka.Builtins import calledWithBuiltinArgumentNamesDecorator
-from nuitka.utils import Utils
+from nuitka.PythonVersions import python_version
 
-from .NodeBases import ExpressionChildrenHavingBase, StatementChildrenHavingBase
+from .NodeBases import (
+    ExpressionChildrenHavingBase,
+    StatementChildrenHavingBase
+)
 from .NodeMakingHelpers import (
     convertNoneConstantToNone,
     makeStatementOnlyNodesFromExpressions
@@ -56,13 +59,13 @@ class ExpressionBuiltinEval(ExpressionChildrenHavingBase):
     getGlobals = ExpressionChildrenHavingBase.childGetter("globals")
     getLocals = ExpressionChildrenHavingBase.childGetter("locals")
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         # TODO: Attempt for constant values to do it.
         return self, None, None
 
 
 # Note: Python3 only so far.
-if Utils.python_version >= 300:
+if python_version >= 300:
     class ExpressionBuiltinExec(ExpressionBuiltinEval):
         kind = "EXPRESSION_BUILTIN_EXEC"
 
@@ -76,13 +79,13 @@ if Utils.python_version >= 300:
             )
 
         def needsLocalsDict(self):
-            return False
+            return True
 
-        def computeExpression(self, constraint_collection):
+        def computeExpression(self, trace_collection):
             # TODO: Attempt for constant values to do it.
             return self, None, None
 
-        def computeExpressionDrop(self, statement, constraint_collection):
+        def computeExpressionDrop(self, statement, trace_collection):
             if self.getParentVariableProvider().isEarlyClosure():
                 result = StatementExec(
                     source_code = self.getSourceCode(),
@@ -92,13 +95,13 @@ if Utils.python_version >= 300:
                 )
 
                 return result, "new_statements", """\
-Replaced builtin exec call to exec statement in early closure context."""
+Replaced built-in exec call to exec statement in early closure context."""
             else:
                 return statement, None, None
 
 
 # Note: Python2 only
-if Utils.python_version < 300:
+if python_version < 300:
     class ExpressionBuiltinExecfile(ExpressionBuiltinEval):
         kind = "EXPRESSION_BUILTIN_EXECFILE"
 
@@ -116,7 +119,7 @@ if Utils.python_version < 300:
         def needsLocalsDict(self):
             return True
 
-        def computeExpressionDrop(self, statement, constraint_collection):
+        def computeExpressionDrop(self, statement, trace_collection):
             # In this case, the copy-back must be done and will only be done
             # correctly by the code for exec statements.
             provider = self.getParentVariableProvider()
@@ -168,14 +171,14 @@ class StatementExec(StatementChildrenHavingBase):
     def needsLocalsDict(self):
         return self.getLocals().mayBeNone()
 
-    def computeStatement(self, constraint_collection):
-        constraint_collection.onExpression(
+    def computeStatement(self, trace_collection):
+        trace_collection.onExpression(
             expression = self.getSourceCode()
         )
         source_code = self.getSourceCode()
 
         if source_code.mayRaiseException(BaseException):
-            constraint_collection.onExceptionRaiseExit(
+            trace_collection.onExceptionRaiseExit(
                 BaseException
             )
 
@@ -189,14 +192,14 @@ class StatementExec(StatementChildrenHavingBase):
 Exec statement raises implicitly when determining source code argument."""
             )
 
-        constraint_collection.onExpression(
+        trace_collection.onExpression(
             expression = self.getGlobals(),
             allow_none = True
         )
         globals_arg = self.getGlobals()
 
         if globals_arg is not None and globals_arg.mayRaiseException(BaseException):
-            constraint_collection.onExceptionRaiseExit(
+            trace_collection.onExceptionRaiseExit(
                 BaseException
             )
 
@@ -216,14 +219,14 @@ Exec statement raises implicitly when determining source code argument."""
 Exec statement raises implicitly when determining globals argument."""
             )
 
-        constraint_collection.onExpression(
+        trace_collection.onExpression(
             expression = self.getLocals(),
             allow_none = True
         )
         locals_arg = self.getLocals()
 
         if locals_arg is not None and locals_arg.mayRaiseException(BaseException):
-            constraint_collection.onExceptionRaiseExit(
+            trace_collection.onExceptionRaiseExit(
                 BaseException
             )
 
@@ -244,7 +247,7 @@ Exec statement raises implicitly when determining globals argument."""
 Exec statement raises implicitly when determining locals argument."""
             )
 
-        constraint_collection.onExceptionRaiseExit(
+        trace_collection.onExceptionRaiseExit(
             BaseException
         )
 
@@ -283,11 +286,11 @@ class StatementLocalsDictSync(StatementChildrenHavingBase):
             source_ref = source_ref,
         )
 
-    def computeStatement(self, constraint_collection):
+    def computeStatement(self, trace_collection):
         if self.getParentVariableProvider().isCompiledPythonModule():
             return None, "new_statements", "Removed sync back to locals without locals."
 
-        constraint_collection.removeAllKnowledge()
+        trace_collection.removeAllKnowledge()
 
         return self, None, None
 
@@ -331,8 +334,8 @@ class ExpressionBuiltinCompile(ExpressionChildrenHavingBase):
     getDontInherit = ExpressionChildrenHavingBase.childGetter("dont_inherit")
     getOptimize = ExpressionChildrenHavingBase.childGetter("optimize")
 
-    def computeExpression(self, constraint_collection):
-        constraint_collection.onExceptionRaiseExit(BaseException)
+    def computeExpression(self, trace_collection):
+        trace_collection.onExceptionRaiseExit(BaseException)
 
         # TODO: Attempt for constant values to do it.
         return self, None, None
