@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -26,6 +26,7 @@ import math
 from nuitka import PythonOperators
 
 from .NodeBases import ExpressionChildrenHavingBase
+from .shapes.StandardShapes import ShapeUnknown, vshape_unknown
 
 
 class ExpressionOperationBase(ExpressionChildrenHavingBase):
@@ -91,13 +92,70 @@ class ExpressionOperationBinary(ExpressionOperationBase):
             source_ref = source_ref
         )
 
-    def computeExpression(self, constraint_collection):
-        # This is using many returns based on many conditions,
-        # pylint: disable=R0912
+    @staticmethod
+    def isExpressionOperationBinary():
+        return True
+
+    def computeExpression(self, trace_collection):
+        operator = self.getOperator()
+        operands = self.getOperands()
+
+        assert operator not in ("Mult", "Add")
+
+        left, right = operands
+
+        if left.isCompileTimeConstant() and right.isCompileTimeConstant():
+            left_value = left.getCompileTimeConstant()
+            right_value = right.getCompileTimeConstant()
+
+            return trace_collection.getCompileTimeComputationResult(
+                node        = self,
+                computation = lambda : self.getSimulator()(
+                    left_value,
+                    right_value
+                ),
+                description = "Operator '%s' with constant arguments." % operator
+            )
 
         # TODO: May go down to MemoryError for compile time constant overflow
         # ones.
-        constraint_collection.onExceptionRaiseExit(BaseException)
+        trace_collection.onExceptionRaiseExit(BaseException)
+
+        # The value of these nodes escaped and could change its contents.
+        trace_collection.removeKnowledge(left)
+        trace_collection.removeKnowledge(right)
+
+        # Any code could be run, note that.
+        trace_collection.onControlFlowEscape(self)
+
+        return self, None, None
+
+    def getOperands(self):
+        return (self.getLeft(), self.getRight())
+
+    getLeft = ExpressionChildrenHavingBase.childGetter("left")
+    getRight = ExpressionChildrenHavingBase.childGetter("right")
+
+
+class ExpressionOperationBinaryAdd(ExpressionOperationBinary):
+    kind = "EXPRESSION_OPERATION_BINARY_ADD"
+
+    def __init__(self, left, right, source_ref):
+        ExpressionOperationBinary.__init__(
+            self,
+            operator   = "Add",
+            left       = left,
+            right      = right,
+            source_ref = source_ref
+        )
+
+    def getDetails(self):
+        return {}
+
+    def computeExpression(self, trace_collection):
+        # TODO: May go down to MemoryError for compile time constant overflow
+        # ones.
+        trace_collection.onExceptionRaiseExit(BaseException)
 
         operator = self.getOperator()
         operands = self.getOperands()
@@ -108,11 +166,133 @@ class ExpressionOperationBinary(ExpressionOperationBase):
             left_value = left.getCompileTimeConstant()
             right_value = right.getCompileTimeConstant()
 
-            if operator == "Mult" and right.isNumberConstant():
+            if left.isKnownToBeIterable(None) and \
+               right.isKnownToBeIterable(None):
+
+                iter_length = left.getIterationLength() + \
+                              right.getIterationLength()
+
+                if iter_length > 256:
+                    return self, None, None
+
+            return trace_collection.getCompileTimeComputationResult(
+                node        = self,
+                computation = lambda : self.getSimulator()(
+                    left_value,
+                    right_value
+                ),
+                description = "Operator '%s' with constant arguments." % operator
+            )
+
+        # The value of these nodes escaped and could change its contents.
+        trace_collection.removeKnowledge(left)
+        trace_collection.removeKnowledge(right)
+
+        # Any code could be run, note that.
+        trace_collection.onControlFlowEscape(self)
+
+        return self, None, None
+
+
+class ShapeLargeConstantValue:
+    def __init__(self, size, shape):
+        self.size = size
+        self.shape = shape
+
+    def getTypeShape(self):
+        return self.shape
+
+    @staticmethod
+    def isConstant():
+        return True
+
+    def hasShapeSlotLen(self):
+        return self.shape.hasShapeSlotLen()
+
+
+class ShapeLargeConstantValuePredictable(ShapeLargeConstantValue):
+    def __init__(self, size, predictor, shape):
+        ShapeLargeConstantValue.__init__(self, size, shape)
+
+        self.predictor = predictor
+
+
+class ExpressionOperationBinaryMult(ExpressionOperationBinary):
+    kind = "EXPRESSION_OPERATION_BINARY_MULT"
+
+    def __init__(self, left, right, source_ref):
+        ExpressionOperationBinary.__init__(
+            self,
+            operator   = "Mult",
+            left       = left,
+            right      = right,
+            source_ref = source_ref
+        )
+
+        self.shape = None
+
+    def getDetails(self):
+        return {}
+
+    def getValueShape(self):
+        if self.shape is not None:
+            return self.shape
+        else:
+            return vshape_unknown
+
+    def getTypeShape(self):
+        if self.shape is not None:
+            return self.shape.getTypeShape()
+        else:
+            return ShapeUnknown
+
+    def getIterationLength(self):
+        left_length = self.getLeft().getIterationLength()
+
+        if left_length is not None:
+            right_value = self.getRight().getIntegerValue()
+
+            if right_value is not None:
+                return left_length * right_value
+
+        right_length = self.getRight().getIterationLength()
+
+        if right_length is not None:
+            left_value = self.getLeft().getIntegerValue()
+
+            if left_value is not None:
+                return right_length * left_value
+
+        return ExpressionOperationBase.getIterationLength(self)
+
+    def computeExpression(self, trace_collection):
+        # TODO: May go down to MemoryError for compile time constant overflow
+        # ones.
+        trace_collection.onExceptionRaiseExit(BaseException)
+
+        # Nothing to do anymore for large constants.
+        if self.shape is not None and self.shape.isConstant():
+            return self, None, None
+
+        left  = self.getLeft()
+        right = self.getRight()
+
+        if left.isCompileTimeConstant() and right.isCompileTimeConstant():
+            left_value = left.getCompileTimeConstant()
+            right_value = right.getCompileTimeConstant()
+
+            if right.isNumberConstant():
                 iter_length = left.getIterationLength()
 
                 if iter_length is not None:
-                    if iter_length * right_value > 256:
+                    size = iter_length * right_value
+                    if size > 256:
+                        self.shape = ShapeLargeConstantValuePredictable(
+                            size      = size,
+                            predictor = None, # predictValuesFromRightAndLeftValue,
+                            shape     = left.getTypeShape()
+                        )
+
                         return self, None, None
 
                 if left.isNumberConstant():
@@ -125,45 +305,78 @@ class ExpressionOperationBinary(ExpressionOperationBase):
                             if math.log10(abs(left_value)) + math.log10(abs(right_value)) > 20:
                                 return self, None, None
 
-            elif operator == "Mult" and left.isNumberConstant():
+            elif left.isNumberConstant():
                 iter_length = right.getIterationLength()
 
                 if iter_length is not None:
+                    size = iter_length * left_value
                     if iter_length * left_value > 256:
+                        self.shape = ShapeLargeConstantValuePredictable(
+                            size      = size,
+                            predictor = None, # predictValuesFromRightAndLeftValue,
+                            shape     = right.getTypeShape()
+                        )
+
                         return self, None, None
-            elif operator == "Add" and \
-                left.isKnownToBeIterable(None) and \
-                right.isKnownToBeIterable(None):
 
-                iter_length = left.getIterationLength() + \
-                              right.getIterationLength()
-
-                if iter_length > 256:
-                    return self, None, None
-
-            return constraint_collection.getCompileTimeComputationResult(
+            return trace_collection.getCompileTimeComputationResult(
                 node        = self,
                 computation = lambda : self.getSimulator()(
                     left_value,
                     right_value
                 ),
-                description = "Operator '%s' with constant arguments." % operator
+                description = "Operator '*' with constant arguments."
             )
-        else:
-            # The value of these nodes escaped and could change its contents.
-            constraint_collection.removeKnowledge(left)
-            constraint_collection.removeKnowledge(right)
 
-            # Any code could be run, note that.
-            constraint_collection.onControlFlowEscape(self)
+        # The value of these nodes escaped and could change its contents.
+        trace_collection.removeKnowledge(left)
+        trace_collection.removeKnowledge(right)
 
-            return self, None, None
+        # Any code could be run, note that.
+        trace_collection.onControlFlowEscape(self)
 
-    def getOperands(self):
-        return (self.getLeft(), self.getRight())
+        return self, None, None
 
-    getLeft = ExpressionChildrenHavingBase.childGetter("left")
-    getRight = ExpressionChildrenHavingBase.childGetter("right")
+    def extractSideEffects(self):
+        left_length = self.getLeft().getIterationLength()
+
+        if left_length is not None:
+            right_value = self.getRight().getIntegerValue()
+
+            if right_value is not None:
+                return self.getLeft().extractSideEffects() + self.getRight().extractSideEffects()
+
+        right_length = self.getRight().getIterationLength()
+
+        if right_length is not None:
+            left_value = self.getLeft().getIntegerValue()
+
+            if left_value is not None:
+                return self.getLeft().extractSideEffects() + self.getRight().extractSideEffects()
+
+        return ExpressionOperationBinary.extractSideEffects(self)
+
+
+def makeBinaryOperationNode(operator, left, right, source_ref):
+    if operator == "Add":
+        return ExpressionOperationBinaryAdd(
+            left       = left,
+            right      = right,
+            source_ref = source_ref
+        )
+    elif operator == "Mult":
+        return ExpressionOperationBinaryMult(
+            left       = left,
+            right      = right,
+            source_ref = source_ref
+        )
+    else:
+        return ExpressionOperationBinary(
+            operator   = operator,
+            left       = left,
+            right      = right,
+            source_ref = source_ref
+        )
 
 
 class ExpressionOperationUnary(ExpressionOperationBase):
@@ -184,14 +397,14 @@ class ExpressionOperationUnary(ExpressionOperationBase):
             source_ref = source_ref
         )
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         operator = self.getOperator()
         operand = self.getOperand()
 
         if operand.isCompileTimeConstant():
             operand_value = operand.getCompileTimeConstant()
 
-            return constraint_collection.getCompileTimeComputationResult(
+            return trace_collection.getCompileTimeComputationResult(
                 node        = self,
                 computation = lambda : self.getSimulator()(
                     operand_value,
@@ -201,13 +414,13 @@ class ExpressionOperationUnary(ExpressionOperationBase):
         else:
             # TODO: May go down to MemoryError for compile time constant overflow
             # ones.
-            constraint_collection.onExceptionRaiseExit(BaseException)
+            trace_collection.onExceptionRaiseExit(BaseException)
 
             # The value of that node escapes and could change its contents.
-            constraint_collection.removeKnowledge(operand)
+            trace_collection.removeKnowledge(operand)
 
             # Any code could be run, note that.
-            constraint_collection.onControlFlowEscape(self)
+            trace_collection.onControlFlowEscape(self)
 
             return self, None, None
 
@@ -235,14 +448,15 @@ class ExpressionOperationNOT(ExpressionOperationUnary):
     def getDetails(self):
         return {}
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         return self.getOperand().computeExpressionOperationNot(
-            not_node              = self,
-            constraint_collection = constraint_collection
+            not_node         = self,
+            trace_collection = trace_collection
         )
 
     def mayRaiseException(self, exception_type):
-        return self.getOperand().mayRaiseExceptionBool(exception_type)
+        return self.getOperand().mayRaiseException(exception_type) or \
+               self.getOperand().mayRaiseExceptionBool(exception_type)
 
     def mayRaiseExceptionBool(self, exception_type):
         return self.getOperand().mayRaiseExceptionBool(exception_type)
@@ -294,7 +508,7 @@ class ExpressionOperationBinaryInplace(ExpressionOperationBinary):
     def isExpressionOperationBinary():
         return True
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         # In-place operation requires extra care to avoid corruption of
         # values.
         left = self.getLeft()
@@ -305,30 +519,30 @@ class ExpressionOperationBinaryInplace(ExpressionOperationBinary):
             assert not left.isMutable(), self
             source_ref = self.getSourceReference()
 
-            result = ExpressionOperationBinary(
+            result = makeBinaryOperationNode(
+                operator   = self.getOperator()[1:],
                 left       = left,
                 right      = right,
-                operator   = self.getOperator()[1:],
                 source_ref = source_ref
             )
 
-            constraint_collection.signalChange(
+            trace_collection.signalChange(
                 tags       = "new_expression",
                 source_ref = source_ref,
                 message    = """\
 Lowered in-place binary operation of compile time constant to binary operation."""
             )
 
-            return result.computeExpression(constraint_collection)
+            return result.computeExpression(trace_collection)
 
         # Any exception may be raised.
-        constraint_collection.onExceptionRaiseExit(BaseException)
+        trace_collection.onExceptionRaiseExit(BaseException)
 
         # The value of these nodes escaped and could change its contents.
-        constraint_collection.removeKnowledge(left)
-        constraint_collection.removeKnowledge(right)
+        trace_collection.removeKnowledge(left)
+        trace_collection.removeKnowledge(right)
 
         # Any code could be run, note that.
-        constraint_collection.onControlFlowEscape(self)
+        trace_collection.onControlFlowEscape(self)
 
         return self, None, None
