@@ -53,6 +53,8 @@ class ExpressionSideEffects(ExpressionChildrenHavingBase):
     }
 
     def __init__(self, side_effects, expression, source_ref):
+        assert len(side_effects)
+
         ExpressionChildrenHavingBase.__init__(
             self,
             values     = {
@@ -70,7 +72,7 @@ class ExpressionSideEffects(ExpressionChildrenHavingBase):
     def isExpressionSideEffects(self):
         return True
 
-    def computeExpression(self, constraint_collection):
+    def computeExpression(self, trace_collection):
         side_effects = self.getSideEffects()
         new_side_effects = []
 
@@ -89,12 +91,12 @@ class ExpressionSideEffects(ExpressionChildrenHavingBase):
 
             return expression, "new_expression", "Remove nested side effects."
 
-        if new_side_effects != side_effects:
-            self.setSideEffects(new_side_effects)
-
         if not new_side_effects:
             return expression, "new_expression", "Removed empty side effects."
 
+        if new_side_effects != side_effects:
+            self.setSideEffects(new_side_effects)
+
         return self, None, None
 
     def willRaiseException(self, exception_type):
@@ -107,7 +109,7 @@ class ExpressionSideEffects(ExpressionChildrenHavingBase):
     def getTruthValue(self):
         return self.getExpression().getTruthValue()
 
-    def computeExpressionDrop(self, statement, constraint_collection):
+    def computeExpressionDrop(self, statement, trace_collection):
         # Side effects can  become statements.
 
         expressions = self.getSideEffects() + (self.getExpression(),)
