@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,7 +25,6 @@ own these functions to a random module.
 
 from nuitka.nodes.ModuleNodes import PythonInternalModule
 from nuitka.SourceCodeReferences import fromFilename
-from nuitka.VariableRegistry import addVariableUsage
 
 internal_module = None
 
@@ -35,13 +34,11 @@ internal_source_ref = fromFilename("internal").atInternal()
 def once_decorator(func):
     func.cached_value = None
 
+    # TODO: This doesn't much specific anymore.
     def replacement():
         if func.cached_value is None:
             func.cached_value = func()
 
-        for variable in func.cached_value.getVariables():
-            addVariableUsage(variable, func.cached_value)
-
         return func.cached_value
 
     return replacement
