@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -33,10 +33,13 @@ from nuitka.nodes.AttributeNodes import (
     ExpressionAttributeLookup,
     ExpressionAttributeLookupSpecial
 )
-from nuitka.nodes.CallNodes import ExpressionCallEmpty, ExpressionCallNoKeywords
+from nuitka.nodes.CallNodes import (
+    ExpressionCallEmpty,
+    ExpressionCallNoKeywords
+)
 from nuitka.nodes.ComparisonNodes import ExpressionComparisonIs
 from nuitka.nodes.ConditionalNodes import StatementConditional
-from nuitka.nodes.ConstantRefNodes import ExpressionConstantRef
+from nuitka.nodes.ConstantRefNodes import makeConstantRefNode
 from nuitka.nodes.ContainerMakingNodes import ExpressionMakeTuple
 from nuitka.nodes.CoroutineNodes import ExpressionAsyncWait
 from nuitka.nodes.ExceptionNodes import (
@@ -48,8 +51,8 @@ from nuitka.nodes.StatementNodes import (
     StatementExpressionOnly,
     StatementsSequence
 )
+from nuitka.PythonVersions import python_version
 from nuitka.tree.Helpers import makeReraiseExceptionStatement
-from nuitka.utils import Utils
 
 from .Helpers import (
     buildNode,
@@ -60,8 +63,8 @@ from .Helpers import (
     makeStatementsSequenceFromStatement
 )
 from .ReformulationAssignmentStatements import buildAssignmentStatements
-from . \
-    ReformulationTryExceptStatements import makeTryExceptSingleHandlerNodeWithPublish
+from .ReformulationTryExceptStatements import \
+    makeTryExceptSingleHandlerNodeWithPublish
 from .ReformulationTryFinallyStatements import makeTryFinallyStatement
 
 
@@ -127,7 +130,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
 
     # The "__enter__" and "__exit__" were normal attribute lookups under
     # CPython2.6, but that changed with CPython2.7.
-    if Utils.python_version < 270:
+    if python_version < 270:
         attribute_lookup_class = ExpressionAttributeLookup
     else:
         attribute_lookup_class = ExpressionAttributeLookupSpecial
@@ -171,7 +174,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
             variable   = tmp_exit_variable,
             source_ref = source_ref
         ),
-        args       = ExpressionConstantRef(
+        args       = makeConstantRefNode(
             constant   = (None, None, None),
             source_ref = source_ref
         ),
@@ -233,7 +236,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
                 variable   = tmp_indicator_variable,
                 source_ref = source_ref
             ),
-            source       = ExpressionConstantRef(
+            source       = makeConstantRefNode(
                 constant   = True,
                 source_ref = source_ref
             ),
@@ -257,7 +260,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
                                 variable   = tmp_indicator_variable,
                                 source_ref = source_ref
                             ),
-                            source       = ExpressionConstantRef(
+                            source       = makeConstantRefNode(
                                 constant   = False,
                                 source_ref = source_ref
                             ),
@@ -274,7 +277,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
                     ),
                     source_ref = source_ref
                 ),
-                public_exc     = Utils.python_version >= 270,
+                public_exc     = python_version >= 270,
                 source_ref     = source_ref
             ),
             final      = StatementConditional(
@@ -283,7 +286,7 @@ def _buildWithNode(provider, context_expr, assign_target, body, body_lineno,
                         variable   = tmp_indicator_variable,
                         source_ref = source_ref
                     ),
-                    right      = ExpressionConstantRef(
+                    right      = makeConstantRefNode(
                         constant   = True,
                         source_ref = source_ref
                     ),
